@@ -58,7 +58,7 @@ def _k8_dashboard(context: "Context", output_path: str) -> None:
         )
         scraper_image = (
             f"{context.account_id}.dkr.ecr.{context.region}.amazonaws.com/"
-            f"orbit-{context.name}-k8-metrics-scraper:{ImagesManifest.k8_dashboard.version}"
+            f"orbit-{context.name}-k8-metrics-scraper:{ImagesManifest.k8_metrics_scraper.version}"
         )
     else:
         dashboard_image = f"{ImagesManifest.k8_dashboard.repository}:{ImagesManifest.k8_dashboard.version}"
@@ -91,6 +91,27 @@ def _metrics_server(context: "Context", output_path: str) -> None:
         file.write(content)
 
 
+def _cluster_autoscaler(output_path: str, context: "Context") -> None:
+    filename = "07-cluster-autoscaler-autodiscover.yaml"
+    input = os.path.join(MODELS_PATH, "apps", filename)
+    output = os.path.join(output_path, filename)
+
+    if context.networking.data.internet_accessible is False:
+        image = (
+            f"{context.account_id}.dkr.ecr.{context.region}.amazonaws.com/"
+            f"orbit-{context.name}-cluster-autoscaler:{ImagesManifest.cluster_autoscaler.version}"
+        )
+    else:
+        image = f"{ImagesManifest.cluster_autoscaler.repository}:{ImagesManifest.cluster_autoscaler.version}"
+    with open(input, "r") as file:
+        content: str = file.read()
+    content = content.replace("$", "").format(
+        account_id=context.account_id, env_name=context.name, cluster_name=f"orbit-{context.name}", image=image
+    )
+    with open(output, "w") as file:
+        file.write(content)
+
+
 def _team(context: "Context", team_context: "TeamContext", output_path: str) -> None:
     input = os.path.join(MODELS_PATH, "apps", "01-team.yaml")
     output = os.path.join(output_path, f"01-{team_context.name}-team.yaml")
@@ -170,6 +191,7 @@ def _landing_page(output_path: str, context: "Context") -> None:
         user_pool_id=context.user_pool_id,
         user_pool_client_id=context.user_pool_client_id,
         identity_pool_id=context.identity_pool_id,
+        ssl_cert_arn=context.networking.frontend.ssl_cert_arn,
         tag=context.images.landing_page.version,
         cognito_external_provider=context.cognito_external_provider,
         cognito_external_provider_label=label,
@@ -206,6 +228,7 @@ def _generate_env_manifest(context: "Context", clean_up: bool = True) -> str:
 
     _landing_page(output_path=output_path, context=context)
     _k8_dashboard(output_path=output_path, context=context)
+    _cluster_autoscaler(output_path=output_path, context=context)
 
     return output_path
 
@@ -257,7 +280,7 @@ def fetch_kubectl_data(context: "Context", k8s_context: str, include_teams: bool
         name="kubernetes-dashboard", k8s_context=k8s_context, namespace="kubernetes-dashboard"
     )
 
-    context.landing_page_url = f"http://{landing_page_url}"
+    context.landing_page_url = f"https://{landing_page_url}"
     context.k8_dashboard_url = f"http://{k8_dashboard_url}"
 
     _update_elbs(context=context)
